==> freecad_0.19.1%2Bdfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Points/Gui/Resources/translations/Points_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Versti į taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Versti į taškus</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Eksportuoti taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Eksportuoti taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Importuoti taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Importuoja taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="320"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="321"/>
      <source>Merge point clouds</source>
      <translation>Apjungti taškų aibes</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="322"/>
      <location filename="../../Command.cpp" line="324"/>
      <source>Merge several point clouds into one</source>
      <translation>Apjungti kelias taškų aibes į vieną</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="275"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="276"/>
      <source>Cut point cloud</source>
      <translation>Apkarpyti taškų aibę</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="277"/>
      <location filename="../../Command.cpp" line="279"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Apkarpyti taškų aibę pasirinktu daugiakampiu</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="363"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="364"/>
      <source>Structured point cloud</source>
      <translation>Sutvarkytų taškų aibė</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="365"/>
      <location filename="../../Command.cpp" line="367"/>
      <source>Convert points to structured point cloud</source>
      <translation>Paversti taškus sutvarkytų taškų aibe</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Keisti taškus</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Mėginti pakeisti taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation type="unfinished">Import points</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation type="unfinished">Transform points</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Convert to points</source>
      <translation>Versti į taškus</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="468"/>
      <location filename="../../ViewProvider.cpp" line="627"/>
      <source>Cut points</source>
      <translation type="unfinished">Cut points</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>ASCII taškų importavimas</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Šablonas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Ypatingosios linijos</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="72"/>
      <source>Ignore lines starting with:</source>
      <translation>Nepaisyti linijų, prasidedančių:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="79"/>
      <source>Cluster by lines starting with:</source>
      <translation>Sutelkti pagal linijas, pradedančias:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="88"/>
      <source>First line:</source>
      <translation>Pirmoji linija:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="100"/>
      <source>Ignore</source>
      <translation>Nepaisyti</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="110"/>
      <source>Number of points</source>
      <translation>Taškų skaičius</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Taško formatas</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="147"/>
      <location filename="../../DlgPointsRead.ui" line="176"/>
      <location filename="../../DlgPointsRead.ui" line="233"/>
      <source>none</source>
      <translation>joks</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="152"/>
      <location filename="../../DlgPointsRead.ui" line="181"/>
      <location filename="../../DlgPointsRead.ui" line="238"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (erdvinis normalės vektorius)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="157"/>
      <location filename="../../DlgPointsRead.ui" line="186"/>
      <location filename="../../DlgPointsRead.ui" line="243"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (plokštuminis normalės vektorius)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="162"/>
      <location filename="../../DlgPointsRead.ui" line="191"/>
      <location filename="../../DlgPointsRead.ui" line="248"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (spalvos dedamosios)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <location filename="../../DlgPointsRead.ui" line="196"/>
      <location filename="../../DlgPointsRead.ui" line="253"/>
      <source>I (Gray value)</source>
      <translation>I (pilko atpalvio reikšmė)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="204"/>
      <source>Number separator:</source>
      <translation>Skaičiaus skyriklis:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="211"/>
      <location filename="../../DlgPointsRead.ui" line="218"/>
      <location filename="../../DlgPointsRead.ui" line="225"/>
      <source>Next block:</source>
      <translation>Sekantis blokas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="270"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="275"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="280"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="289"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="294"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="302"/>
      <source>Points format:</source>
      <translation>Taškų formatas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Peržiūrėti</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Peržiūrėtų eilučių kiekis:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="348"/>
      <source>100</source>
      <translation>100</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Taškų formatai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Visi failai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="202"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="203"/>
      <source>Enter maximum distance:</source>
      <translation>Įveskite didžiausią atstumą:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Points tools</source>
      <translation>Įrankiai darbui su taškais</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="38"/>
      <source>&amp;Points</source>
      <translation>&amp;Taškai</translation>
    </message>
  </context>
</TS>

==> freecad_0.20.2%2Bdfsg1.orig.tar.xz: FreeCAD-0.20.2/src/Mod/Points/Gui/Resources/translations/Points_lt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lt" sourcelanguage="en">
  <context>
    <name>CmdPointsConvert</name>
    <message>
      <location filename="../../Command.cpp" line="189"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="190"/>
      <source>Convert to points...</source>
      <translation>Versti į taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="191"/>
      <location filename="../../Command.cpp" line="193"/>
      <source>Convert to points</source>
      <translation>Versti į taškus</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="112"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="113"/>
      <source>Export points...</source>
      <translation>Eksportuoti taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="114"/>
      <location filename="../../Command.cpp" line="116"/>
      <source>Exports a point cloud</source>
      <translation>Eksportuoti taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location filename="../../Command.cpp" line="67"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="68"/>
      <source>Import points...</source>
      <translation>Importuoti taškus...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <location filename="../../Command.cpp" line="71"/>
      <source>Imports a point cloud</source>
      <translation>Importuoja taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsMerge</name>
    <message>
      <location filename="../../Command.cpp" line="326"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="327"/>
      <source>Merge point clouds</source>
      <translation>Apjungti taškų aibes</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="328"/>
      <location filename="../../Command.cpp" line="330"/>
      <source>Merge several point clouds into one</source>
      <translation>Apjungti kelias taškų aibes į vieną</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location filename="../../Command.cpp" line="281"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="282"/>
      <source>Cut point cloud</source>
      <translation>Apkarpyti taškų aibę</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="283"/>
      <location filename="../../Command.cpp" line="285"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Apkarpyti taškų aibę pasirinktu daugiakampiu</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsStructure</name>
    <message>
      <location filename="../../Command.cpp" line="369"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="370"/>
      <source>Structured point cloud</source>
      <translation>Sutvarkytų taškų aibė</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="371"/>
      <location filename="../../Command.cpp" line="373"/>
      <source>Convert points to structured point cloud</source>
      <translation>Paversti taškus sutvarkytų taškų aibe</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location filename="../../Command.cpp" line="152"/>
      <source>Points</source>
      <translation>Taškai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="153"/>
      <source>Transform Points</source>
      <translation>Keisti taškus</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="154"/>
      <location filename="../../Command.cpp" line="156"/>
      <source>Test to transform a point cloud</source>
      <translation>Mėginti pakeisti taškų aibę</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="88"/>
      <source>Import points</source>
      <translation>Importuoti taškus</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="168"/>
      <source>Transform points</source>
      <translation>Keisti taškus</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="214"/>
      <source>Convert to points</source>
      <translation>Versti į taškus</translation>
    </message>
    <message>
      <location filename="../../ViewProvider.cpp" line="467"/>
      <location filename="../../ViewProvider.cpp" line="626"/>
      <source>Cut points</source>
      <translation>Iškirpti taškus</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="14"/>
      <source>ASCII points import</source>
      <translation>ASCII taškų importavimas</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="34"/>
      <source>Template:</source>
      <translation>Šablonas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="46"/>
      <source>Special lines</source>
      <translation>Ypatingosios linijos</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="58"/>
      <source>First line:</source>
      <translation>Pirmoji linija:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="70"/>
      <source>Ignore</source>
      <translation>Nepaisyti</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="80"/>
      <source>Number of points</source>
      <translation>Taškų skaičius</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="101"/>
      <source>Cluster by lines starting with:</source>
      <translation>Sutelkti pagal linijas, pradedančias:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="111"/>
      <source>Ignore lines starting with:</source>
      <translation>Nepaisyti linijų, prasidedančių:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="126"/>
      <source>Point format</source>
      <translation>Taško formatas</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="146"/>
      <source>Number separator:</source>
      <translation>Skaičiaus skyriklis:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="157"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="162"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="167"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="172"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="180"/>
      <source>Points format:</source>
      <translation>Taškų formatas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="188"/>
      <source>X,Y,Z</source>
      <translation>X, Y, Z</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="193"/>
      <source>X,Y</source>
      <translation>X, Y</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="201"/>
      <location filename="../../DlgPointsRead.ui" line="237"/>
      <location filename="../../DlgPointsRead.ui" line="273"/>
      <source>Next block:</source>
      <translation>Sekantis blokas:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="209"/>
      <location filename="../../DlgPointsRead.ui" line="245"/>
      <location filename="../../DlgPointsRead.ui" line="281"/>
      <source>none</source>
      <translation>joks</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="214"/>
      <location filename="../../DlgPointsRead.ui" line="250"/>
      <location filename="../../DlgPointsRead.ui" line="286"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (erdvinis normalės vektorius)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="219"/>
      <location filename="../../DlgPointsRead.ui" line="255"/>
      <location filename="../../DlgPointsRead.ui" line="291"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (plokštuminis normalės vektorius)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="224"/>
      <location filename="../../DlgPointsRead.ui" line="260"/>
      <location filename="../../DlgPointsRead.ui" line="296"/>
      <source>R,G,B (color)</source>
      <translation>R, G, B (spalvos dedamosios)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="229"/>
      <location filename="../../DlgPointsRead.ui" line="265"/>
      <location filename="../../DlgPointsRead.ui" line="301"/>
      <source>I (Gray value)</source>
      <translation>I (pilko atpalvio reikšmė)</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="314"/>
      <source>Preview</source>
      <translation>Peržiūrėti</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="341"/>
      <source>Number of previewed lines:</source>
      <translation>Peržiūrėtų eilučių kiekis:</translation>
    </message>
    <message>
      <location filename="../../DlgPointsRead.ui" line="348"/>
      <source>100</source>
      <translation>100</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>Point formats</source>
      <translation>Taškų formatai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="81"/>
      <location filename="../../Command.cpp" line="129"/>
      <source>All Files</source>
      <translation>Visi failai</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="208"/>
      <source>Distance</source>
      <translation type="unfinished">Distance</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="209"/>
      <source>Enter maximum distance:</source>
      <translation>Įveskite didžiausią atstumą:</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="37"/>
      <source>Points tools</source>
      <translation>Įrankiai darbui su taškais</translation>
    </message>
    <message>
      <location filename="../../Workbench.cpp" line="38"/>
      <source>&amp;Points</source>
      <translation>&amp;Taškai</translation>
    </message>
  </context>
</TS>
